## pyenlone

Python3 wrapper of enl.one REST APIs:
- https://v.enl.one
- https://tasks.enl.one
- https://status.enl.one (Not very soon, but soon)
For more info: https://wiki.enl.one/doku.php?id=start

To install:
    `pip3 install pyenlone`

# Have a look at the /examples !
- /tasks/party_op.py shows an integral example of organizing an operation
- /tasks/ops_you_helped.py shows how to use both APIs with VOAuth
# You'll need to have an apikey from:
https://v.enl.one/apikey
Or to set up oauth from:
https://v.enl.one/oauth/clients
For Tasks api you can also use Google API, Rocks, enl.io or Firebase for OAuth
(not really tested though)

# Documentation for V Api can be found
here https://v.enl.one/apikey
and here https://v.enl.one/oauth/clients

# And documentation for Tasks API is
here https://wiki.enl.one/doku.php?id=t_basic_documentation


# TODO
- Add webhooks and sockets and other things I don't really understand to Tasks
-
